@@ -42,19 +42,27 @@ namespace URLHelpers {
 
 // Needs to be big enough to hold an IDN-encoded name.
 // For host names bigger than this, we won't do IDN encoding, which is almost certainly OK.
-const unsigned hostNameBufferLength = 2048;
-const unsigned urlBytesBufferLength = 2048;
+constexpr unsigned hostNameBufferLength = 2048;
+constexpr unsigned urlBytesBufferLength = 2048;
 
-static uint32_t IDNScriptWhiteList[(USCRIPT_CODE_LIMIT + 31) / 32];
+// This needs to be higher than the UScriptCode for any of the scripts on the IDN allowed list.
+// At one point we used USCRIPT_CODE_LIMIT from ICU, but there are two reasons not to use it.
+// 1) ICU considers it deprecated, so by setting U_HIDE_DEPRECATED we can't see it.
+// 2) No good reason to limit ourselves to scripts that existed in the ICU headers when
+//    WebKit was compiled.
+// This is only really important for platforms that load an external IDN allowed script list.
+// Not important for the compiled-in one.
+constexpr auto scriptCodeLimit = static_cast<UScriptCode>(256);
+
+static uint32_t allowedIDNScriptBits[(scriptCodeLimit + 31) / 32];
 
 #if !PLATFORM(COCOA)
 
-// Cocoa has an implementation that uses a whitelist in /Library or ~/Library,
-// if it exists.
-void loadIDNScriptWhiteList()
+// Cocoa has an implementation that reads this from a file in /Library or ~/Library.
+void loadIDNAllowedScriptList()
 {
     static std::once_flag flag;
-    std::call_once(flag, initializeDefaultIDNScriptWhiteList);
+    std::call_once(flag, initializeDefaultIDNAllowedScriptList);
 }
 
 #endif // !PLATFORM(COCOA)
@@ -104,7 +112,7 @@ static bool isLookalikeCharacter(const Optional<UChar32>& previousCodePoint, UCh
     // any non-printable character, any character considered as whitespace,
     // any ignorable character, and emoji characters related to locks.
     
-    // We also considered the characters in Mozilla's blacklist <http://kb.mozillazine.org/Network.IDN.blacklist_chars>.
+    // We also considered the characters in Mozilla's list of characters <http://kb.mozillazine.org/Network.IDN.blacklist_chars>.
 
     // Some of the characters here will never appear once ICU has encoded.
     // For example, ICU transforms most spaces into an ASCII space and most
@@ -122,8 +130,10 @@ static bool isLookalikeCharacter(const Optional<UChar32>& previousCodePoint, UCh
     /* 0x0131 LATIN SMALL LETTER DOTLESS I is intentionally not considered a lookalike character because it is visually distinguishable from i and it has legitimate use in the Turkish language. */
     case 0x01C0: /* LATIN LETTER DENTAL CLICK */
     case 0x01C3: /* LATIN LETTER RETROFLEX CLICK */
+    case 0x0237: /* LATIN SMALL LETTER DOTLESS J */
     case 0x0251: /* LATIN SMALL LETTER ALPHA */
     case 0x0261: /* LATIN SMALL LETTER SCRIPT G */
+    case 0x0274: /* LATIN LETTER SMALL CAPITAL N */
     case 0x027E: /* LATIN SMALL LETTER R WITH FISHHOOK */
     case 0x02D0: /* MODIFIER LETTER TRIANGULAR COLON */
     case 0x0335: /* COMBINING SHORT STROKE OVERLAY */
@@ -256,47 +266,56 @@ static bool isLookalikeCharacter(const Optional<UChar32>& previousCodePoint, UCh
     }
 }
 
-void whiteListIDNScript(const char* scriptName)
+static void addScriptToIDNAllowedScriptList(int32_t script)
 {
-    int32_t script = u_getPropertyValueEnum(UCHAR_SCRIPT, scriptName);
-    if (script >= 0 && script < USCRIPT_CODE_LIMIT) {
+    if (script >= 0 && script < scriptCodeLimit) {
         size_t index = script / 32;
         uint32_t mask = 1 << (script % 32);
-        IDNScriptWhiteList[index] |= mask;
+        allowedIDNScriptBits[index] |= mask;
     }
 }
 
-void initializeDefaultIDNScriptWhiteList()
+static void addScriptToIDNAllowedScriptList(UScriptCode script)
 {
-    const char* defaultIDNScriptWhiteList[20] = {
-        "Common",
-        "Inherited",
-        "Arabic",
-        "Armenian",
-        "Bopomofo",
-        "Canadian_Aboriginal",
-        "Devanagari",
-        "Deseret",
-        "Gujarati",
-        "Gurmukhi",
-        "Hangul",
-        "Han",
-        "Hebrew",
-        "Hiragana",
-        "Katakana_Or_Hiragana",
-        "Katakana",
-        "Latin",
-        "Tamil",
-        "Thai",
-        "Yi",
-    };
-    for (const char* scriptName : defaultIDNScriptWhiteList)
-        whiteListIDNScript(scriptName);
+    addScriptToIDNAllowedScriptList(static_cast<int32_t>(script));
 }
 
-static bool allCharactersInIDNScriptWhiteList(const UChar* buffer, int32_t length)
+void addScriptToIDNAllowedScriptList(const char* scriptName)
 {
-    loadIDNScriptWhiteList();
+    addScriptToIDNAllowedScriptList(u_getPropertyValueEnum(UCHAR_SCRIPT, scriptName));
+}
+
+void initializeDefaultIDNAllowedScriptList()
+{
+    constexpr UScriptCode scripts[] = {
+        USCRIPT_COMMON,
+        USCRIPT_INHERITED,
+        USCRIPT_ARABIC,
+        USCRIPT_ARMENIAN,
+        USCRIPT_BOPOMOFO,
+        USCRIPT_CANADIAN_ABORIGINAL,
+        USCRIPT_DEVANAGARI,
+        USCRIPT_DESERET,
+        USCRIPT_GUJARATI,
+        USCRIPT_GURMUKHI,
+        USCRIPT_HANGUL,
+        USCRIPT_HAN,
+        USCRIPT_HEBREW,
+        USCRIPT_HIRAGANA,
+        USCRIPT_KATAKANA_OR_HIRAGANA,
+        USCRIPT_KATAKANA,
+        USCRIPT_LATIN,
+        USCRIPT_TAMIL,
+        USCRIPT_THAI,
+        USCRIPT_YI,
+    };
+    for (auto script : scripts)
+        addScriptToIDNAllowedScriptList(script);
+}
+
+static bool allCharactersInAllowedIDNScriptList(const UChar* buffer, int32_t length)
+{
+    loadIDNAllowedScriptList();
     int32_t i = 0;
     Optional<UChar32> previousCodePoint;
     while (i < length) {
@@ -312,12 +331,12 @@ static bool allCharactersInIDNScriptWhiteList(const UChar* buffer, int32_t lengt
             LOG_ERROR("got negative number for script code from ICU: %d", script);
             return false;
         }
-        if (script >= USCRIPT_CODE_LIMIT)
+        if (script >= scriptCodeLimit)
             return false;
 
         size_t index = script / 32;
         uint32_t mask = 1 << (script % 32);
-        if (!(IDNScriptWhiteList[index] & mask))
+        if (!(allowedIDNScriptBits[index] & mask))
             return false;
         
         if (isLookalikeCharacter(previousCodePoint, c))
@@ -526,7 +545,7 @@ static bool allCharactersAllowedByTLDRules(const UChar* buffer, int32_t length)
 }
 
 // Return value of null means no mapping is necessary.
-Optional<String> mapHostName(const String& hostName, const Optional<URLDecodeFunction>& decodeFunction)
+Optional<String> mapHostName(const String& hostName, URLDecodeFunction decodeFunction)
 {
     if (hostName.length() > hostNameBufferLength)
         return String();
@@ -555,7 +574,7 @@ Optional<String> mapHostName(const String& hostName, const Optional<URLDecodeFun
     if (numCharactersConverted == static_cast<int32_t>(length) && !memcmp(sourceBuffer.data(), destinationBuffer, length * sizeof(UChar)))
         return String();
 
-    if (!decodeFunction && !allCharactersInIDNScriptWhiteList(destinationBuffer, numCharactersConverted) && !allCharactersAllowedByTLDRules(destinationBuffer, numCharactersConverted))
+    if (!decodeFunction && !allCharactersInAllowedIDNScriptList(destinationBuffer, numCharactersConverted) && !allCharactersAllowedByTLDRules(destinationBuffer, numCharactersConverted))
         return String();
 
     return String(destinationBuffer, numCharactersConverted);
@@ -563,7 +582,7 @@ Optional<String> mapHostName(const String& hostName, const Optional<URLDecodeFun
 
 using MappingRangesVector = Optional<Vector<std::tuple<unsigned, unsigned, String>>>;
 
-static void collectRangesThatNeedMapping(const String& string, unsigned location, unsigned length, MappingRangesVector& array, const Optional<URLDecodeFunction>& decodeFunction)
+static void collectRangesThatNeedMapping(const String& string, unsigned location, unsigned length, MappingRangesVector& array, URLDecodeFunction decodeFunction)
 {
     // Generally, we want to optimize for the case where there is one host name that does not need mapping.
     // Therefore, we use null to indicate no mapping here and an empty array to indicate error.
@@ -581,7 +600,7 @@ static void collectRangesThatNeedMapping(const String& string, unsigned location
         array->constructAndAppend(location, length, *host);
 }
 
-static void applyHostNameFunctionToMailToURLString(const String& string, const Optional<URLDecodeFunction>& decodeFunction, MappingRangesVector& array)
+static void applyHostNameFunctionToMailToURLString(const String& string, URLDecodeFunction decodeFunction, MappingRangesVector& array)
 {
     // In a mailto: URL, host names come after a '@' character and end with a '>' or ',' or '?' character.
     // Skip quoted strings so that characters in them don't confuse us.
@@ -653,7 +672,7 @@ static void applyHostNameFunctionToMailToURLString(const String& string, const O
     }
 }
 
-static void applyHostNameFunctionToURLString(const String& string, const Optional<URLDecodeFunction>& decodeFunction, MappingRangesVector& array)
+static void applyHostNameFunctionToURLString(const String& string, URLDecodeFunction decodeFunction, MappingRangesVector& array)
 {
     // Find hostnames. Too bad we can't use any real URL-parsing code to do this,
     // but we have to do it before doing all the %-escaping, and this is the only
@@ -696,7 +715,7 @@ static void applyHostNameFunctionToURLString(const String& string, const Optiona
     collectRangesThatNeedMapping(string, hostNameStart, hostNameEnd - hostNameStart, array, decodeFunction);
 }
 
-String mapHostNames(const String& string, const Optional<URLDecodeFunction>& decodeFunction)
+String mapHostNames(const String& string, URLDecodeFunction decodeFunction)
 {
     // Generally, we want to optimize for the case where there is one host name that does not need mapping.
     
@@ -852,7 +871,7 @@ String userVisibleURL(const CString& url)
 
     if (mayNeedHostNameDecoding) {
         // FIXME: Is it good to ignore the failure of mapHostNames and keep result intact?
-        auto mappedResult = mapHostNames(result, nullopt);
+        auto mappedResult = mapHostNames(result, nullptr);
         if (!!mappedResult)
             result = mappedResult;
     }
